From a1b47866821db0b4a394f49a8692935f4b346f83 Mon Sep 17 00:00:00 2001
From: Jake Sanders <jake@micro.mu>
Date: Mon, 14 Oct 2019 12:04:49 +0100
Subject: [PATCH] TLS -> ToS

---
 api/server/acme/acme.go | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/api/server/acme/acme.go b/api/server/acme/acme.go
index 9d61816a..cecf49e0 100644
--- a/api/server/acme/acme.go
+++ b/api/server/acme/acme.go
@@ -45,8 +45,8 @@ type Options struct {
 	Cache interface{}
 }
 
-// AcceptTLS indicates whether you accept your CA's terms of service
-func AcceptTLS(b bool) Option {
+// AcceptToS indicates whether you accept your CA's terms of service
+func AcceptToS(b bool) Option {
 	return func(o *Options) {
 		o.AcceptToS = b
 	}
@@ -78,7 +78,7 @@ func OnDemand(b bool) Option {
 // Default uses the Let's Encrypt Production CA, with DNS Challenge disabled.
 func Default() []Option {
 	return []Option{
-		AcceptTLS(true),
+		AcceptToS(true),
 		CA(LetsEncryptProductionCA),
 		OnDemand(true),
 	}